@@ -9,27 +9,30 @@ from smartmin.models import SmartModel
 
 def generate_file_path(instance, filename):
 
-    file_path_prefix = 'csv_imports/'
+    file_path_prefix = "csv_imports/"
 
     name, extension = os.path.splitext(filename)
 
     if len(name) + len(extension) >= 100:
-        name = name[:100-len(extension)-len(file_path_prefix)]
+        name = name[: 100 - len(extension) - len(file_path_prefix)]
 
     return "%s%s%s" % (file_path_prefix, name, extension)
 
 
 class ImportTask(SmartModel):
-    PENDING = 'PENDING'
-    STARTED = 'STARTED'
-    RUNNING = 'RUNNING'
-    SUCCESS = 'SUCCESS'
-    FAILURE = 'FAILURE'
+    PENDING = "PENDING"
+    STARTED = "STARTED"
+    RUNNING = "RUNNING"
+    SUCCESS = "SUCCESS"
+    FAILURE = "FAILURE"
 
     READY_STATES = [SUCCESS, FAILURE]
 
-    csv_file = models.FileField(upload_to=generate_file_path, verbose_name="Import file",
-                                help_text="A comma delimited file of records to import")
+    csv_file = models.FileField(
+        upload_to=generate_file_path,
+        verbose_name="Import file",
+        help_text="A comma delimited file of records to import",
+    )
 
     model_class = models.CharField(max_length=255, help_text="The model we are importing for")
 
@@ -45,12 +48,13 @@ class ImportTask(SmartModel):
 
     def start(self):
         from .tasks import csv_import
+
         self.log("Queued import at %s" % timezone.now())
         self.task_status = self.STARTED
-        self.save(update_fields=['import_log', 'task_status'])
+        self.save(update_fields=["import_log", "task_status"])
         result = csv_import.delay(self.pk)
         self.task_id = result.task_id
-        self.save(update_fields=['task_id'])
+        self.save(update_fields=["task_id"])
 
     def done(self):
         if self.task_id:
@@ -62,7 +66,7 @@ class ImportTask(SmartModel):
     def log(self, message):
         self.import_log += "%s\n" % message
         self.modified_on = timezone.now()
-        self.save(update_fields=['import_log', 'modified_on'])
+        self.save(update_fields=["import_log", "modified_on"])
 
     def __unicode__(self):
         return "%s Import" % import_string(self.model_class)._meta.verbose_name.title()
