@@ -1,12 +1,10 @@
-
 from collections import OrderedDict
 from datetime import datetime
 from enum import Enum
+from textwrap import dedent
 
 import sqlparse
-from sqlparse import sql, tokens
-from sqlparse import tokens as sql_tokens
-from textwrap import dedent
+from sqlparse import sql, tokens, tokens as sql_tokens
 
 from django.core.management.base import BaseCommand
 from django.db.migrations import RunSQL
@@ -22,6 +20,7 @@ class SqlType(Enum):
     """
     The different SQL types that we can extract from migrations
     """
+
     INDEX = 1
     FUNCTION = 2
     TRIGGER = 3
@@ -45,9 +44,9 @@ class SqlObjectOperation:
         if tokens[0].ttype != sql_tokens.DDL or tokens[1].ttype != sql_tokens.Keyword:
             return None
 
-        if tokens[0].value.upper() in ('CREATE', 'CREATE OR REPLACE'):
+        if tokens[0].value.upper() in ("CREATE", "CREATE OR REPLACE"):
             is_create = True
-        elif tokens[0].value.upper() in ('DROP',):
+        elif tokens[0].value.upper() in ("DROP",):
             is_create = False
         else:
             return None
@@ -85,8 +84,12 @@ class SqlObjectOperation:
         return f"{func.get_name()}({','.join(types)})"
 
     def __eq__(self, other):
-        return self.statement == other.statement and self.sql_type == other.sql_type \
-               and self.obj_name == other.obj_name and self.is_create == other.is_create
+        return (
+            self.statement == other.statement
+            and self.sql_type == other.sql_type
+            and self.obj_name == other.obj_name
+            and self.is_create == other.is_create
+        )
 
     def __repr__(self):
         return f"SqlObjectOperation[type={self.sql_type} name='{self.obj_name}' is_create={self.is_create}]"
@@ -97,19 +100,25 @@ class Command(BaseCommand):
 
     def add_arguments(self, parser):
         parser.add_argument(
-            '--preserve-order', action='store_true', dest='preserve_order', default=False,
-            help='Whether to preserve order of operations rather than sorting by object name.',
+            "--preserve-order",
+            action="store_true",
+            dest="preserve_order",
+            default=False,
+            help="Whether to preserve order of operations rather than sorting by object name.",
         )
         parser.add_argument(
-            '--output-dir', action='store', dest='output_dir', default='temba/sql',
-            help='The output directory for generated SQL files.',
+            "--output-dir",
+            action="store",
+            dest="output_dir",
+            default="temba/sql",
+            help="The output directory for generated SQL files.",
         )
 
     def handle(self, *args, **options):
-        preserve_order = options.get('preserve_order')
-        output_dir = options.get('output_dir')
+        preserve_order = options.get("preserve_order")
+        output_dir = options.get("output_dir")
 
-        self.verbosity = options.get('verbosity')
+        self.verbosity = options.get("verbosity")
 
         self.stdout.write("Loading migrations...")
 
@@ -203,21 +212,21 @@ class Command(BaseCommand):
                 by_type[obj_type] = sorted(ops, key=lambda o: o.obj_name)
 
         if by_type[SqlType.INDEX]:
-            self.write_dump('indexes', by_type[SqlType.INDEX], output_dir)
+            self.write_dump("indexes", by_type[SqlType.INDEX], output_dir)
         if by_type[SqlType.FUNCTION]:
-            self.write_dump('functions', by_type[SqlType.FUNCTION], output_dir)
+            self.write_dump("functions", by_type[SqlType.FUNCTION], output_dir)
         if by_type[SqlType.TRIGGER]:
-            self.write_dump('triggers', by_type[SqlType.TRIGGER], output_dir)
+            self.write_dump("triggers", by_type[SqlType.TRIGGER], output_dir)
 
     def write_dump(self, type_label, operations, output_dir):  # pragma: no cover
-        filename = '%s/current_%s.sql' % (output_dir, type_label)
+        filename = "%s/current_%s.sql" % (output_dir, type_label)
 
-        with open(filename, 'w') as f:
-            header = '-- Generated by collect_sql on %s UTC\n\n' % datetime.utcnow().strftime("%Y-%m-%d %H:%M")
+        with open(filename, "w") as f:
+            header = "-- Generated by collect_sql on %s UTC\n\n" % datetime.utcnow().strftime("%Y-%m-%d %H:%M")
             f.write(header)
 
             for operation in operations:
                 f.write(operation.statement)
-                f.write('\n\n')
+                f.write("\n\n")
 
         self.stdout.write("Saved %s" % filename)
