@@ -10,9 +10,10 @@ class PassRequestToFormMixin(object):
     """
     Mixin to include the request in the form kwargs
     """
+
     def get_form_kwargs(self):
         kwargs = super(PassRequestToFormMixin, self).get_form_kwargs()
-        kwargs['request'] = self.request
+        kwargs["request"] = self.request
         return kwargs
 
 
@@ -20,6 +21,7 @@ class NonAtomicMixin(object):
     """
     Mixin to configure a view to be handled without a transaction
     """
+
     @method_decorator(transaction.non_atomic_requests)
     def dispatch(self, request, *args, **kwargs):
         return super(NonAtomicMixin, self).dispatch(request, *args, **kwargs)
