@@ -7,10 +7,11 @@ def assign_perm(perm, group):
     """
     if not isinstance(perm, Permission):
         try:
-            app_label, codename = perm.split('.', 1)
+            app_label, codename = perm.split(".", 1)
         except ValueError:
-            raise ValueError("For global permissions, first argument must be in"
-                             " format: 'app_label.codename' (is %r)" % perm)
+            raise ValueError(
+                "For global permissions, first argument must be in" " format: 'app_label.codename' (is %r)" % perm
+            )
         perm = Permission.objects.get(content_type__app_label=app_label, codename=codename)
 
     group.permissions.add(perm)
@@ -23,10 +24,11 @@ def remove_perm(perm, group):
     """
     if not isinstance(perm, Permission):
         try:
-            app_label, codename = perm.split('.', 1)
+            app_label, codename = perm.split(".", 1)
         except ValueError:
-            raise ValueError("For global permissions, first argument must be in"
-                             " format: 'app_label.codename' (is %r)" % perm)
+            raise ValueError(
+                "For global permissions, first argument must be in" " format: 'app_label.codename' (is %r)" % perm
+            )
         perm = Permission.objects.get(content_type__app_label=app_label, codename=codename)
 
     group.permissions.remove(perm)
